@@ -109,6 +109,37 @@ def smart_comment_uncomment(txt: str) -> Tuple[str, int]:
                 res_deltas.append(0)
         return '\n'.join(res_lines), res_deltas
 
+INLINE_CODE_REGEX = re.compile(r'`([^`]+)`')
+def clean_docstring(content: str) -> str:
+    paragraphs = ['']
+    in_code = False
+
+    def par():
+        if paragraphs[-1]:
+            paragraphs.append('')
+
+    for line in content.splitlines():
+        if not line or line.isspace():
+            par()
+            continue
+        if line.startswith('```'):
+            par()
+            in_code = not in_code
+            continue
+
+        if in_code:
+            if paragraphs[-1]:
+                paragraphs[-1] += '\n'
+            paragraphs[-1] += line
+        else:
+            if paragraphs[-1]:
+                paragraphs[-1] += '\n' if line[0].isspace() else ' '
+            paragraphs[-1] += line
+
+    res = '\n\n'.join(paragraphs).strip()
+    res = re.sub(INLINE_CODE_REGEX, r'\1', res)
+    return res
+
 _img_cache = {}
 _error_image = Image.new('RGB', (50, 50), (252, 3, 244))
 def load_image(img_url: str, *, scale: float = 1):
@@ -204,9 +235,9 @@ class StartStopButton(tk.Button):
         self.show_play()
 
     def show_play(self):
-        self.config(text = '⚑', bg = '#2d9e29', fg = 'white')
+        self.config(text = '⚑', bg = '#2d9e29', activebackground = '#23b81d', fg = 'white', activeforeground = 'white')
     def show_stop(self):
-        self.config(text = '◾', bg = '#b31515', fg = 'white')
+        self.config(text = '◾', bg = '#b31515', activebackground = '#d10d0d', fg = 'white', activeforeground = 'white')
 
 class Content(tk.Frame):
     def __init__(self, parent):
@@ -680,6 +711,7 @@ class CodeEditor(ScrolledText):
 
         self.text.bind('<Tab>', lambda e: self.do_tab())
         self.text.bind('<BackSpace>', lambda e: self.do_backspace())
+        self.text.bind('<Return>', lambda e: self.do_newline())
 
         if color_enabled:
             # source: https://stackoverflow.com/questions/38594978/tkinter-syntax-highlighting-for-text-widget
@@ -718,6 +750,9 @@ class CodeEditor(ScrolledText):
     def show_full_help(self):
         if not force_enabled or content is None or content.project is None:
             return
+        if self.text.compare('end-1c', '==', '1.0'):
+            return # if our text is empty, don't do anything
+
         script = jedi.Script(content.project.get_full_script())
         self.update_highlighting(script)
 
@@ -732,11 +767,9 @@ class CodeEditor(ScrolledText):
         else:
             self.hide_suggestion()
 
-    def update_highlighting(self, script = None):
+    def update_highlighting(self, script):
         if not force_enabled or content is None or content.project is None:
             return
-        if script is None:
-            script = jedi.Script(content.project.get_full_script())
 
         self.text.tag_delete('jedi-syntax-err')
         for err in script.get_syntax_errors():
@@ -751,11 +784,9 @@ class CodeEditor(ScrolledText):
         edit_col += self.column_offset
         return edit_line, edit_col
 
-    def show_docs(self, script = None):
+    def show_docs(self, script):
         if not force_enabled or content is None or content.project is None:
             return
-        if script is None:
-            script = jedi.Script(content.project.get_full_script())
 
         edit_line, edit_col = self.total_pos()
         docs = script.help(edit_line, edit_col)
@@ -769,7 +800,9 @@ class CodeEditor(ScrolledText):
         docs = [x for x in docs if x] # don't show empty items
 
         if docs: # if nothing to show, don't change the display
-            content.display.docs.set_text('\n\n----------\n\n'.join(docs))
+            raw = '\n\n----------\n\n'.join(docs)
+            clean = clean_docstring(raw)
+            content.display.docs.set_text(clean)
 
     def show_suggestion(self, script = None):
         if not force_enabled or content is None or content.project is None:
@@ -835,11 +868,24 @@ class CodeEditor(ScrolledText):
         self.text.tag_add(tk.SEL, new_sel_start, new_sel_end)
         self.text.mark_set(tk.INSERT, new_ins)
 
+    def do_newline(self):
+        line = self.text.get('insert linestart', 'insert')
+        white, _ = get_white_nonwhite(line)
+        if line.endswith(':'):
+            white += '    '
+        self.text.insert('insert', '\n' + white)
+        return 'break'
+
     def do_backspace(self):
+        # if there's a selection, use default behavior
+        if self.text.tag_ranges(tk.SEL):
+            return
+
+        # otherwise try deleting back to a tab stop
         col = int(self.text.index(tk.INSERT).split('.')[1])
         if col != 0:
             del_count = (col % 4) or 4 # delete back to previous tab column
-            pos = f'insert - {del_count} chars'
+            pos = f'insert-{del_count}c'
             if self.text.get(pos, 'insert').isspace():
                 self.text.delete(pos, 'insert')
                 return 'break' # override default behavior
@@ -892,7 +938,7 @@ def _yield_(x):
         return self.prefix + self.text.get('1.0', 'end-1c')
 
 class StageEditor(CodeEditor):
-    prefix_lines = 2
+    prefix_lines = 3
     blocks = []
 
     def __init__(self, parent, *, name: str, value: str):
@@ -902,10 +948,10 @@ class StageEditor(CodeEditor):
 
     def get_script(self):
         raw = self.text.get('1.0', 'end-1c')
-        return f'@netsblox.turtle.stage\nclass {self.name}(netsblox.turtle.StageBase):\n{indent(raw)}\n{self.name} = {self.name}()'
+        return f'@netsblox.turtle.stage\nclass {self.name}(netsblox.turtle.StageBase):\n    pass\n{indent(raw)}\n{self.name} = {self.name}()'
 
 class TurtleEditor(CodeEditor):
-    prefix_lines = 2
+    prefix_lines = 3
     blocks = []
 
     def __init__(self, parent, *, name: str, value: str):
@@ -915,7 +961,7 @@ class TurtleEditor(CodeEditor):
 
     def get_script(self):
         raw = self.text.get('1.0', 'end-1c')
-        return f'@netsblox.turtle.turtle\nclass {self.name}(netsblox.turtle.TurtleBase):\n{indent(raw)}\n{self.name} = {self.name}()'
+        return f'@netsblox.turtle.turtle\nclass {self.name}(netsblox.turtle.TurtleBase):\n    pass\n{indent(raw)}\n{self.name} = {self.name}()'
 
 class Display(tk.Frame):
     def __init__(self, parent):
@@ -924,6 +970,8 @@ class Display(tk.Frame):
         self.docs = ScrolledText(self, readonly = True)
         self.terminal = TerminalOutput(self)
 
+        self.docs.text.configure(wrap = tk.WORD)
+
         self.docs.grid(row = 0, column = 0, sticky = tk.NSEW)
         self.terminal.grid(row = 1, column = 0, sticky = tk.NSEW)
 
@@ -988,9 +1036,10 @@ class TurtleDisplay(tk.Frame):
         # ScrolledCanvas has better behavior, but we dont actually want scrollbars, so always match display size
         self.canvas.bind('<Configure>', lambda e: self.screen.screensize(canvwidth = e.width, canvheight = e.height))
 
+MENU_STYLE = { 'tearoff': False, 'relief': 'flat', 'bg': '#bdbdbd' }
 class MainMenu(tk.Menu):
     def __init__(self, parent):
-        super().__init__(parent)
+        super().__init__(parent, **MENU_STYLE)
 
         self.project_path = None
 
@@ -999,11 +1048,11 @@ class MainMenu(tk.Menu):
                 root.destroy()
         root.protocol('WM_DELETE_WINDOW', kill)
 
-        submenu = tk.Menu(self, tearoff = False)
-        submenu.add_command(label = 'New', command = self.new_project)
-        submenu.add_command(label = 'Open', command = self.open_project)
+        submenu = tk.Menu(self, **MENU_STYLE)
+        submenu.add_command(label = 'New', command = self.new_project, accelerator = 'Ctrol+N')
+        submenu.add_command(label = 'Open', command = self.open_project, accelerator = 'Ctrl+O')
         submenu.add_separator()
-        submenu.add_command(label = 'Save', command = self.save)
+        submenu.add_command(label = 'Save', command = self.save, accelerator = 'Ctrl+S')
         submenu.add_command(label = 'Save As', command = self.save_as)
         submenu.add_separator()
         submenu.add_command(label = 'Export', command = self.export_as)
@@ -1011,10 +1060,16 @@ class MainMenu(tk.Menu):
         submenu.add_command(label = 'Exit', command = kill)
         self.add_cascade(label = 'File', menu = submenu)
 
-        submenu = tk.Menu(self, tearoff = False)
-        submenu.add_command(label = 'Blocks', command = self.toggle_blocks)
+        root.bind_all('<Control-n>', lambda e: self.new_project())
+        root.bind_all('<Control-o>', lambda e: self.open_project())
+        root.bind_all('<Control-s>', lambda e: self.save())
+
+        submenu = tk.Menu(self, **MENU_STYLE)
+        submenu.add_command(label = 'Blocks', command = self.toggle_blocks, accelerator = 'Ctrl+B')
         self.add_cascade(label = 'View', menu = submenu)
 
+        root.bind_all('<Control-b>', lambda e: self.toggle_blocks())
+
     @property
     def project_path(self):
         return self._project_path
